# -*- coding: utf-8 -*-

from setuptools import setup, find_packages

setup(
    name='{{ app_name }}',
    version='0.0.1',
    description='',
    long_description='',
    author='{{ author_name }}',
    author_email='',
    packages=find_packages(),
    url='{{ app_addr }}',
    include_package_data=True,
    entry_points={
        'console_scripts': [],
    },
    zip_safe=False,
    install_requires=[],
)
