# -*- coding: utf-8 -*-

DATABASE_CONFIG = {
    'host': '{{ database_addr }}',
    'port': '{{ database_port }}',
    'user': '{{ database_user }}',
    'password': '{{ database_password }}',
    'database': '{{ database_db }}',
}

LOG_CONFIG = {
    'version': 1,
    'disable_existing_loggers': False,
    'formatters': {
        'generic': {
            'format': '%(asctime)s [%(process)d] [%(levelname)s] %(name)s: %(message)s',
        },
        'verbose': {
            'format': '[%(process)s][%(levelname)s][%(module)s-%(lineno)d]%(asctime)s %(name)s:%(message)s'
        },
    },
    'handlers': {
        'console': {
            'level': 'INFO',
            'class': 'logging.StreamHandler',
            'formatter': 'generic',
        },
    },
    'loggers': {
        '': {
            'handlers': ['console'],
            'level': 'INFO',
            'propagate': True,
        },
    }
}
